@@ -23,7 +23,7 @@ _units = microsec_units+millisec_units+sec_units+min_units+hr_units+day_units
 _calendars = ['standard', 'gregorian', 'proleptic_gregorian',
               'noleap', 'julian', 'all_leap', '365_day', '366_day', '360_day']
 
-__version__ = '1.4'
+__version__ = '1.4.1'
 
 # Adapted from http://delete.me.uk/2005/03/iso8601.html
 ISO8601_REGEX = re.compile(r"(?P<year>[+-]?[0-9]{1,4})(-(?P<month>[0-9]{1,2})(-(?P<day>[0-9]{1,2})"
@@ -86,7 +86,9 @@ def JulianDayFromDate(date, calendar='standard'):
     month[month_lt_3] = month[month_lt_3] + 12
     year[month_lt_3] = year[month_lt_3] - 1
 
-    A = np.int64(year / 100)
+    # MC - assure array
+    # A = np.int64(year / 100)
+    A = (year / 100).astype(np.int64)
 
     # MC
     # jd = int(365.25 * (year + 4716)) + int(30.6001 * (month + 1)) + \
@@ -98,15 +100,24 @@ def JulianDayFromDate(date, calendar='standard'):
     # the Julian to Gregorian Calendar
     # here assumed to have occurred the day after 1582 October 4
     if calendar in ['standard', 'gregorian']:
-        if np.min(jd) >= 2299170.5:
-            # 1582 October 15 (Gregorian Calendar)
-            B = 2 - A + np.int32(A / 4)
-        elif np.max(jd) < 2299160.5:
-            # 1582 October 5 (Julian Calendar)
-            B = np.zeros(len(jd))
-        else:
+        # MC - do not have to be contiguous dates
+        # if np.min(jd) >= 2299170.5:
+        #     # 1582 October 15 (Gregorian Calendar)
+        #     B = 2 - A + np.int32(A / 4)
+        # elif np.max(jd) < 2299160.5:
+        #     # 1582 October 5 (Julian Calendar)
+        #     B = np.zeros(len(jd))
+        # else:
+        #     print(date, calendar, jd)
+        #     raise ValueError(
+        #         'impossible date (falls in gap between end of Julian calendar and beginning of Gregorian calendar')
+        if np.any((jd >= 2299160.5) & (jd < 2299170.5)): # missing days in Gregorian calendar
             raise ValueError(
                 'impossible date (falls in gap between end of Julian calendar and beginning of Gregorian calendar')
+        B = np.zeros(len(jd))             # 1582 October 5 (Julian Calendar)
+        ii = np.where(jd >= 2299170.5)[0] # 1582 October 15 (Gregorian Calendar)
+        if ii.size>0:
+            B[ii] = 2 - A[ii] + np.int32(A[ii] / 4)
     elif calendar == 'proleptic_gregorian':
         B = 2 - A + np.int32(A / 4)
     elif calendar == 'julian':
@@ -664,6 +675,14 @@ units to datetime objects.
             raise ValueError(
                 "calendar must be one of %s, got '%s'" % (str(_calendars), calendar))
         units, tzoffset, self.origin = _dateparse(unit_string)
+        # real-world calendars limited to positive reference years.
+        if self.calendar in ['julian', 'standard', 'gregorian', 'proleptic_gregorian']:
+            if self.origin.year == 0:
+                msg='zero not allowed as a reference year, does not exist in Julian or Gregorian calendars'
+                raise ValueError(msg)
+            elif self.origin.year < 0:
+                msg='negative reference year in time units, must be >= 1'
+                raise ValueError(msg)
         self.tzoffset = tzoffset  # time zone offset in minutes
         self.units = units
         self.unit_string = unit_string
@@ -901,12 +920,6 @@ def _parse_date(datestring):
     # else:
     #    groups["fraction"] = int(float("0.%s" % groups["fraction"]) * 1e6)
     iyear = int(groups["year"])
-    if iyear == 0:
-        msg='zero not allowed as a reference year, does not exist in Julian or Gregorian calendars'
-        raise ValueError(msg)
-    elif iyear < 0:
-        msg='negative reference year in time units, must be >= 1'
-        raise ValueError(msg)
     return iyear, int(groups["month"]), int(groups["day"]),\
         int(groups["hour"]), int(groups["minute"]), int(groups["second"]),\
         tzoffset_mins
@@ -1002,7 +1015,7 @@ def date2index(dates, nctime, calendar=None, select='exact'):
     an exact match cannot be found. C{nearest} will return the indices that
     correpond to the closest dates.
     """
-    try: 
+    try:
         nctime.units
     except AttributeError:
         raise AttributeError("netcdf time variable is missing a 'units' attribute")
@@ -1040,7 +1053,7 @@ def time2index(times, nctime, calendar=None, select='exact'):
     an exact match cannot be found. C{nearest} will return the indices that
     correpond to the closest times.
     """
-    try: 
+    try:
         nctime.units
     except AttributeError:
         raise AttributeError("netcdf time variable is missing a 'units' attribute")
