@@ -251,24 +251,38 @@ class netcdftimeTestCase(unittest.TestCase):
         assert hash(d3) == hash(d3)
 
         # check datetime immutability
-        with self.assertRaises(AttributeError):
+        # using assertRaises as a context manager
+        # only works with python >= 2.7 (issue #497).
+        #with self.assertRaises(AttributeError):
+        #    d1.year = 1999
+        #with self.assertRaises(AttributeError):
+        #    d1.month = 6
+        #with self.assertRaises(AttributeError):
+        #    d1.day = 5
+        #with self.assertRaises(AttributeError):
+        #    d1.hour = 10
+        #with self.assertRaises(AttributeError):
+        #    d1.minute = 33
+        #with self.assertRaises(AttributeError):
+        #    d1.second = 45
+        #with self.assertRaises(AttributeError):
+        #    d1.dayofwk = 1
+        #with self.assertRaises(AttributeError):
+        #    d1.dayofyr = 52
+        #with self.assertRaises(AttributeError):
+        #    d1.format = '%Y'
+        try:
             d1.year = 1999
-        with self.assertRaises(AttributeError):
             d1.month = 6
-        with self.assertRaises(AttributeError):
             d1.day = 5
-        with self.assertRaises(AttributeError):
             d1.hour = 10
-        with self.assertRaises(AttributeError):
             d1.minute = 33
-        with self.assertRaises(AttributeError):
             d1.second = 45
-        with self.assertRaises(AttributeError):
             d1.dayofwk = 1
-        with self.assertRaises(AttributeError):
             d1.dayofyr = 52
-        with self.assertRaises(AttributeError):
             d1.format = '%Y'
+        except AttributeError:
+            pass
 
         # Check leading white space
         self.assertEqual(
@@ -417,6 +431,39 @@ class netcdftimeTestCase(unittest.TestCase):
         t = datetimex(2001, 12, 1, 2, 3, 4)
         self.assertEqual(t, copy.deepcopy(t))
 
+        # issue 442
+        units = "days since 0000-01-01 00:00:00"
+        # this should fail (year zero not allowed with real-world calendars)
+        try:
+            date2num(datetime(1, 1, 1), units, calendar='standard')
+        except ValueError:
+            pass
+        # this should not fail (year zero allowed in 'fake' calendars)
+        t = date2num(datetime(1, 1, 1), units, calendar='360_day')
+        self.assertEqual(t, 360)
+        d = num2date(t, units, calendar='360_day')
+        self.assertEqual(d, datetimex(1,1,1))
+        d = num2date(0, units, calendar='360_day')
+        self.assertEqual(d, datetimex(0,1,1))
+
+        # list around missing dates in Gregorian calendar
+        # scalar
+        units = 'days since 0001-01-01 12:00:00'
+        t1 = date2num(datetime(1582, 10, 4), units, calendar='gregorian')
+        t2 = date2num(datetime(1582, 10, 15), units, calendar='gregorian')
+        self.assertEqual(t1+1, t2)
+        # list
+        t1, t2 = date2num([datetime(1582, 10, 4), datetime(1582, 10, 15)], units, calendar='gregorian')
+        self.assertEqual(t1+1, t2)
+        t1, t2 = date2num([datetime(1582, 10, 4), datetime(1582, 10, 15)], units, calendar='standard')
+        self.assertEqual(t1+1, t2)
+        # this should fail: days missing in Gregorian calendar
+        try:
+            t1, t2, t3 = date2num([datetime(1582, 10, 4), datetime(1582, 10, 10), datetime(1582, 10, 15)], units, calendar='standard')
+        except ValueError:
+            pass
+
+
 class TestDate2index(unittest.TestCase):
 
     class TestTime:
